@@ -38,6 +38,7 @@ ContextTorch = R6Class("ContextTorch",
     #'   The total number of epochs the learner is trained for.
     #' @param prediction_encoder (`function()`)\cr
     #'   The learner's prediction encoder.
+    #'   See section *Inheriting* of [`LearnerTorch`].
     #' @param eval_freq (`integer(1)`)\cr
     #'   The evaluation frequency.
     #' @param device (`character(1)`)\cr
@@ -111,6 +112,9 @@ ContextTorch = R6Class("ContextTorch",
     #' @field last_loss (`numeric(1)`)\cr
     #' The loss from the last trainings batch.
     last_loss = NULL,
+    #' @field y_hat (`torch_tensor`)\cr
+    #' The model's prediction for the current batch.
+    y_hat = NULL,
     #' @field epoch (`integer(1)`)\cr
     #'   The current epoch.
     epoch = NULL,
