@@ -4,6 +4,10 @@
 #'
 #' @section nn_module:
 #' Calls [`torch::nn_linear()`] with the input and output features inferred from the input shape / task.
+#' For
+#' * binary classification, the output dimension is 1.
+#' * multiclass classification, the output dimension is the number of classes.
+#' * regression, the output dimension is 1.
 #'
 #' @section Parameters:
 #' * `bias` :: `logical(1)`\cr
@@ -36,14 +40,16 @@ PipeOpTorchHead = R6Class("PipeOpTorchHead",
   ),
   private = list(
     .shapes_out = function(shapes_in, param_vals, task) {
-      assert_true(length(shapes_in[[1]]) == 2L)
-      d = get_nout(task)
+      if (length(shapes_in[[1]]) != 2L) {
+        stopf("PipeOpTorchHead expects 2D input, but got %s.", shape_to_str(shapes_in))
+      }
+      d = output_dim_for(task)
       list(c(shapes_in[[1]][[1]], d))
     },
     .shape_dependent_params = function(shapes_in, param_vals, task) {
       param_vals$in_features = shapes_in[[1L]][2L]
 
-      param_vals$out_features = get_nout(task)
+      param_vals$out_features = output_dim_for(task)
 
       param_vals
     }
