@@ -90,7 +90,8 @@ assert_rgb_shape = function(shape) {
 # grayscale or rgb image
 assert_grayscale_or_rgb = function(shape) {
   assert_shape(shape, len = 4L, null_ok = FALSE, only_batch_unknown = TRUE)
-  assert_true(shape[2L] == 3L || shape[2L] == 1L)
+  assert_true(shape[2L] == 3L || shape[2L] == 1L,
+    .var.name = "Second dimension is 3 for RGB images or 1 for grayscale images")
 }
 
 #' @title Infer Shapes
